==> kubernetes-model-admissionregistration-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingWebhookConfigurationListFluent<A extends ValidatingWebhookConfigurationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ValidatingWebhookConfiguration item);
  public A setToItems(Integer index,ValidatingWebhookConfiguration item);
  public A addToItems(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration... items);
  public A addAllToItems(Collection<ValidatingWebhookConfiguration> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration... items);
  public A removeAllFromItems(Collection<ValidatingWebhookConfiguration> items);
  public A removeMatchingFromItems(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingWebhookConfiguration> getItems();
  public List<ValidatingWebhookConfiguration> buildItems();
  public ValidatingWebhookConfiguration buildItem(Integer index);
  public ValidatingWebhookConfiguration buildFirstItem();
  public ValidatingWebhookConfiguration buildLastItem();
  public ValidatingWebhookConfiguration buildMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  public A withItems(List<ValidatingWebhookConfiguration> items);
  public A withItems(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration... items);
  public Boolean hasItems();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItem();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItemLike(ValidatingWebhookConfiguration item);
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> setNewItemLike(Integer index,ValidatingWebhookConfiguration item);
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editItem(Integer index);
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editFirstItem();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editLastItem();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ValidatingWebhookConfigurationFluent<ValidatingWebhookConfigurationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingWebhookConfigurationListFluent<A extends ValidatingWebhookConfigurationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ValidatingWebhookConfiguration item);
  public A setToItems(int index,ValidatingWebhookConfiguration item);
  public A addToItems(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration... items);
  public A addAllToItems(Collection<ValidatingWebhookConfiguration> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration... items);
  public A removeAllFromItems(Collection<ValidatingWebhookConfiguration> items);
  public A removeMatchingFromItems(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingWebhookConfiguration> getItems();
  public List<ValidatingWebhookConfiguration> buildItems();
  public ValidatingWebhookConfiguration buildItem(int index);
  public ValidatingWebhookConfiguration buildFirstItem();
  public ValidatingWebhookConfiguration buildLastItem();
  public ValidatingWebhookConfiguration buildMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  public A withItems(List<ValidatingWebhookConfiguration> items);
  public A withItems(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhookConfiguration... items);
  public Boolean hasItems();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItem();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> addNewItemLike(ValidatingWebhookConfiguration item);
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> setNewItemLike(int index,ValidatingWebhookConfiguration item);
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editItem(int index);
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editFirstItem();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editLastItem();
  public ValidatingWebhookConfigurationListFluent.ItemsNested<A> editMatchingItem(Predicate<ValidatingWebhookConfigurationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ValidatingWebhookConfigurationFluent<ValidatingWebhookConfigurationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
